@@ -95,6 +95,7 @@ struct NtpServer {
 	{ "time1.stupi.se", "Stockholm, Sweden" },
 	{ "goodtime.ijs.si", "Ljubljana, Slovenia" },
 	{ "ntp2.ja.net", "United Kingdom" },
+	{ "laikas.pfi.lt", "Lithuania" },
 	{ NULL }
 };
 
@@ -142,7 +143,7 @@ toggle_ntp_server (GstTimeTool  *tool,
 	OobsList *list;
 	gchar *url;
 
-	list = oobs_ntp_config_get_servers (tool->ntp_config);
+	list = oobs_ntp_config_get_servers (OOBS_NTP_CONFIG (tool->ntp_config));
 
 	gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
 			    COL_ACTIVE, &active,
@@ -162,6 +163,7 @@ toggle_ntp_server (GstTimeTool  *tool,
 		server = (GObject*) oobs_ntp_server_new (url);
 		oobs_list_append (list, &new_list_iter);
 		oobs_list_set (list, &new_list_iter, server);
+		g_object_unref (server);
 
 		gtk_list_store_set (store, &iter,
 				    COL_ACTIVE, active,
@@ -176,6 +178,7 @@ toggle_ntp_server (GstTimeTool  *tool,
 	}
 
 	oobs_object_commit_async (tool->ntp_config, NULL, NULL);
+	oobs_list_iter_free (list_iter);
 	g_free (url);
 }
 
@@ -199,6 +202,7 @@ on_server_toggled (GtkCellRendererToggle *renderer,
 
 	tool = g_object_get_data (G_OBJECT (renderer), "tool");
 	toggle_ntp_server (tool, store, iter);
+	gtk_tree_path_free (path);
 }
 
 static void
@@ -251,7 +255,8 @@ ntp_servers_list_check (GtkWidget     *ntp_list,
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean valid, found;
-	const gchar *str, *address;
+	const gchar *address;
+	gchar *str;
 
 	address = oobs_ntp_server_get_hostname (server);
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ntp_list));
@@ -271,6 +276,7 @@ ntp_servers_list_check (GtkWidget     *ntp_list,
 			found = TRUE;
 		}
 
+		g_free (str);
 		valid = gtk_tree_model_iter_next (model, &iter);
 	}
 
